@@ -5,7 +5,6 @@
     SPDX-License-Identifier: LGPL-2.1-or-later
 */
 
-#include "taglibwritertest.h"
 #include "indexerextractortestsconfig.h"
 #include "writers/taglibwriter.h"
 #include "writedata.h"
@@ -13,28 +12,48 @@
 #include <kfilemetadata/Extractor>
 #include <kfilemetadata/ExtractionResult>
 #include <kfilemetadata/SimpleExtractionResult>
-#include "taglib.h"
-#include "fileref.h"
 
 #include <QTest>
 #include <QFile>
 #include <QMap>
 
+class TagLibWriterTest : public QObject
+{
+    Q_OBJECT
+
+private Q_SLOTS:
+    void initTestCase();
+    void testCommonData();
+    void testCommonData_data();
+    void testExtendedData();
+    void testExtendedData_data();
+    void testRating();
+    void testRating_data();
+    void testComplexContactData();
+    void testComplexContactData_data();
+    void testImageWrite();
+    void testImageWrite_data();
+    void testImageDelete();
+    void testImageDelete_data();
+    void testImageDeleteInsert();
+    void testImageDeleteInsert_data();
+    void testMultiImage();
+    void testMultiImage_data();
+
+private:
+    QByteArray m_coverImage;
+};
+
 using namespace KFileMetaData;
 
-QString TagLibWriterTest::testFilePath(const QString& fileName) const
+namespace
+{
+QString testFilePath(const QString &fileName)
 {
     return QLatin1String(INDEXER_TESTS_SAMPLE_FILES_PATH) + QLatin1Char('/') + fileName;
 }
 
-void TagLibWriterTest::initTestCase()
-{
-    QFile imgFile(testFilePath("cover.jpg"));
-    imgFile.open(QIODevice::ReadOnly);
-    m_coverImage = imgFile.readAll();
-}
-
-void TagLibWriterTest::extractResult(const QString &mimeType, KFileMetaData::ExtractionResult &result)
+void extractResult(const QString &mimeType, KFileMetaData::ExtractionResult &result)
 {
     KFileMetaData::ExtractorCollection extractors;
     QList<KFileMetaData::Extractor*> extractorList = extractors.fetchExtractors(mimeType);
@@ -47,6 +66,14 @@ void TagLibWriterTest::extractResult(const QString &mimeType, KFileMetaData::Ext
     KFileMetaData::Extractor* ex = extractorList.first();
     ex->extract(&result);
 }
+} // <anonymous> namespace
+
+void TagLibWriterTest::initTestCase()
+{
+    QFile imgFile(testFilePath("cover.jpg"));
+    imgFile.open(QIODevice::ReadOnly);
+    m_coverImage = imgFile.readAll();
+}
 
 void TagLibWriterTest::testCommonData()
 {
@@ -156,13 +183,13 @@ void TagLibWriterTest::testCommonData_data()
 
     QTest::addRow("mp3")
         << QStringLiteral("mp3")
-        << QStringLiteral("audio/mpeg3")
+        << QStringLiteral("audio/mpeg")
         << QString()
         ;
 
     QTest::addRow("mp3_unicode")
         << QStringLiteral("mp3")
-        << QStringLiteral("audio/mpeg3")
+        << QStringLiteral("audio/mpeg")
         << unicodeTestStringSuffix
         ;
 
@@ -192,13 +219,13 @@ void TagLibWriterTest::testCommonData_data()
 
     QTest::addRow("opus")
         << QStringLiteral("opus")
-        << QStringLiteral("audio/opus")
+        << QStringLiteral("audio/x-opus+ogg")
         << QString()
         ;
 
     QTest::addRow("opus_unicode")
         << QStringLiteral("opus")
-        << QStringLiteral("audio/opus")
+        << QStringLiteral("audio/x-opus+ogg")
         << unicodeTestStringSuffix
         ;
 
@@ -305,7 +332,7 @@ void TagLibWriterTest::testExtendedData_data()
 
     QTest::addRow("mp3")
         << QStringLiteral("mp3")
-        << QStringLiteral("audio/mpeg3")
+        << QStringLiteral("audio/mpeg")
         ;
 
     QTest::addRow("mpc")
@@ -320,7 +347,7 @@ void TagLibWriterTest::testExtendedData_data()
 
     QTest::addRow("opus")
         << QStringLiteral("opus")
-        << QStringLiteral("audio/opus")
+        << QStringLiteral("audio/x-opus+ogg")
         ;
 
     QTest::addRow("speex")
@@ -397,67 +424,67 @@ void TagLibWriterTest::testRating_data()
 
     QTest::addRow("mp3_0")
         << QStringLiteral("mp3")
-        << QStringLiteral("audio/mpeg3")
+        << QStringLiteral("audio/mpeg")
         << 0
         ;
 
     QTest::addRow("mp3_1")
         << QStringLiteral("mp3")
-        << QStringLiteral("audio/mpeg3")
+        << QStringLiteral("audio/mpeg")
         << 1
         ;
 
     QTest::addRow("mp3_2")
         << QStringLiteral("mp3")
-        << QStringLiteral("audio/mpeg3")
+        << QStringLiteral("audio/mpeg")
         << 2
         ;
 
     QTest::addRow("mp3_3")
         << QStringLiteral("mp3")
-        << QStringLiteral("audio/mpeg3")
+        << QStringLiteral("audio/mpeg")
         << 3
         ;
 
     QTest::addRow("mp3_4")
         << QStringLiteral("mp3")
-        << QStringLiteral("audio/mpeg3")
+        << QStringLiteral("audio/mpeg")
         << 4
         ;
 
     QTest::addRow("mp3_5")
         << QStringLiteral("mp3")
-        << QStringLiteral("audio/mpeg3")
+        << QStringLiteral("audio/mpeg")
         << 5
         ;
 
     QTest::addRow("mp3_6")
         << QStringLiteral("mp3")
-        << QStringLiteral("audio/mpeg3")
+        << QStringLiteral("audio/mpeg")
         << 6
         ;
 
     QTest::addRow("mp3_7")
         << QStringLiteral("mp3")
-        << QStringLiteral("audio/mpeg3")
+        << QStringLiteral("audio/mpeg")
         << 7
         ;
 
     QTest::addRow("mp3_8")
         << QStringLiteral("mp3")
-        << QStringLiteral("audio/mpeg3")
+        << QStringLiteral("audio/mpeg")
         << 8
         ;
 
     QTest::addRow("mp3_9")
         << QStringLiteral("mp3")
-        << QStringLiteral("audio/mpeg3")
+        << QStringLiteral("audio/mpeg")
         << 9
         ;
 
     QTest::addRow("mp3_10")
         << QStringLiteral("mp3")
-        << QStringLiteral("audio/mpeg3")
+        << QStringLiteral("audio/mpeg")
         << 10
         ;
 
@@ -469,7 +496,7 @@ void TagLibWriterTest::testRating_data()
 
     QTest::addRow("opus")
         << QStringLiteral("opus")
-        << QStringLiteral("audio/opus")
+        << QStringLiteral("audio/x-opus+ogg")
         << 6
         ;
 
@@ -593,7 +620,7 @@ void TagLibWriterTest::testComplexContactData_data()
 
     QTest::addRow("mp3")
         << QStringLiteral("mp3")
-        << QStringLiteral("audio/mpeg3")
+        << QStringLiteral("audio/mpeg")
         ;
 
     QTest::addRow("mpc")
@@ -608,7 +635,7 @@ void TagLibWriterTest::testComplexContactData_data()
 
     QTest::addRow("opus")
         << QStringLiteral("opus")
-        << QStringLiteral("audio/opus")
+        << QStringLiteral("audio/x-opus+ogg")
         ;
 
     QTest::addRow("speex")
@@ -669,7 +696,7 @@ void TagLibWriterTest::testImageWrite_data()
 
     QTest::addRow("opus")
             << QStringLiteral("test.opus")
-            << QStringLiteral("audio/opus")
+            << QStringLiteral("audio/x-opus+ogg")
             ;
 
     QTest::addRow("ogg")
@@ -684,7 +711,7 @@ void TagLibWriterTest::testImageWrite_data()
 
     QTest::addRow("mp3")
             << QStringLiteral("test.mp3")
-            << QStringLiteral("audio/mpeg3")
+            << QStringLiteral("audio/mpeg")
             ;
 
     QTest::addRow("m4a")
@@ -841,11 +868,11 @@ void TagLibWriterTest::testMultiImage_data()
 
     using Image = EmbeddedImageData::ImageType;
     QTest::addRow("aiff") << QStringLiteral("test.aif") << QStringLiteral("audio/x-aiff") << ImageTypes{ Image::Other, Image::Artist };
-    QTest::addRow("opus") << QStringLiteral("test.opus") << QStringLiteral("audio/opus") << ImageTypes{ Image::Other, Image::BackCover };
+    QTest::addRow("opus") << QStringLiteral("test.opus") << QStringLiteral("audio/x-opus+ogg") << ImageTypes{ Image::Other, Image::BackCover };
     QTest::addRow("flac") << QStringLiteral("test.flac") << QStringLiteral("audio/flac") << ImageTypes{ Image::Other, Image::Composer };
     QTest::addRow("wma")  << QStringLiteral("test.wma") << QStringLiteral("audio/x-ms-wma") << ImageTypes{ Image::Other, Image::Band };
 }
 
 QTEST_GUILESS_MAIN(TagLibWriterTest)
 
-#include "moc_taglibwritertest.cpp"
+#include "taglibwritertest.moc"
